#
# spec file for package postsrsd
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           postsrsd
Version:        1.12
Release:        bp156.2.6
Summary:        Sender Rewriting Support for postfix
License:        GPL-2.0-only
Group:          Productivity/Networking/Email/Servers
URL:            https://github.com/roehling/postsrsd

Source:         https://github.com/roehling/postsrsd/archive/%version.tar.gz
BuildRequires:  cmake
BuildRequires:  systemd-rpm-macros

%description
PostSRSd provides the Sender Rewriting Scheme (SRS) via TCP-based
lookup tables for Postfix. SRS is needed if your mail server acts
as forwarder.

%prep
%autosetup -p1

%build
%cmake -DGENERATE_SRS_SECRET=0 -DCHROOT_DIR=/var/lib/empty \
	-DUSE_APPARMOR=1 -DINIT_FLAVOR=systemd
%make_jobs

%install
%cmake_install
b="%buildroot"
mkdir -p "$b/%_prefix/lib/systemd/system" "$b/%_defaultdocdir"
mv "$b/%_sysconfdir/systemd/system"/* "$b/%_prefix/lib/systemd/system/"
mv "$b/%_datadir/doc/%name" "$b/%_defaultdocdir/"
cp README.md "$b/%_defaultdocdir/%name/"
ln -s service "$b/%_sbindir/rcpostsrsd"

%pre
%service_add_pre postsrsd.service

%post
s="%_sysconfdir/postsrsd.secret"
if [ ! -e "$s" ]; then
	echo "No postsrsd secret found in $s, generating one."
	dd if=/dev/urandom of="$s" bs=64 count=1
fi
%service_add_post postsrsd.service

%preun
%service_del_preun postsrsd.service

%postun
%service_del_postun postsrsd.service

%files
%dir %_sysconfdir/apparmor.d
%config %_sysconfdir/apparmor.d/*
%config(noreplace) %_sysconfdir/default/postsrsd
%ghost %_sysconfdir/postsrsd.secret
%_sbindir/postsrsd
%_sbindir/rcpostsrsd
%_prefix/lib/systemd/system/*.service
%_docdir/%name/
%_datadir/postsrsd/
%license LICENSE

%changelog
* Wed Aug 17 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.12
  * Explicitly clear O_NONBLOCK to avoid inherited non-blocking
    sockets on some operating systems
  * Do not close all file descriptors up to _SC_MAX_OPEN, that
    limit can be absurdly high and hang PostSRSd for minutes
* Mon Apr 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.11 [boo#1180251]
  * Drop group privileges as well as user privileges
  * Fixed: The subprocess that talks to Postfix could be caused
    to hang with a very long email address. [CVE-2020-35573]
* Fri Dec 20 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6
  * Fix endianness issue with SHA-1 implementation
  * Add dual stack support
  * Make SRS separator configurable
* Tue Nov 18 2014 jengelh@inai.de
- Initial package for build.opensuse.org (version 1.2+git2)
